==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Binary/ClearBits.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+12)
#define CT_v197	((void*)startLabel+44)
#define F0_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+52)
#define FN_NHC_46Binary_46hs_95clearBits	((void*)startLabel+64)
#define CT_v199	((void*)startLabel+88)
#define CF_NHC_46Binary_46hs_95clearBits	((void*)startLabel+96)
#define CT_v201	((void*)startLabel+156)
#define FN_LAMBDA194	((void*)startLabel+192)
#define CT_v203	((void*)startLabel+216)
#define F0_LAMBDA194	((void*)startLabel+224)
#define ST_v200	((void*)startLabel+232)
#define ST_v202	((void*)startLabel+253)
#define ST_v198	((void*)startLabel+280)
#define ST_v196	((void*)startLabel+304)
extern Node TM_NHC_46Binary[];
void FR_NHC_46Binary_46hs_95clearBits_35(void);
extern Node TM_NHC_46Binary[];
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node TM_NHC_46Binary[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46Binary[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v197)
,	/* FN_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v196)
,	/* CT_v197: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v199)
,	/* FN_NHC_46Binary_46hs_95clearBits: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95clearBits: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v201)
,};
Node FN_NHC_46Binary_46clearBits[] = {
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 140001
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46Binary_46clearBits[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46clearBits),2)
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v203)
,	/* FN_LAMBDA194: (byte 0) */
  useLabel(TMSUB_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 150011
, useLabel(ST_v202)
,	/* CT_v203: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA194: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v200: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,99)
, bytes2word(108,101,97,114)
, bytes2word(66,105,116,115)
,	/* ST_v202: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(97,114,121,46)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
, bytes2word(115,58,49,53)
,	/* ST_v198: (byte 4) */
  bytes2word(58,49,49,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,99,108)
, bytes2word(101,97,114,66)
,	/* ST_v196: (byte 4) */
  bytes2word(105,116,115,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,99,108)
, bytes2word(101,97,114,66)
, bytes2word(105,116,115,35)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_clearBits" NHC.Binary.hs_clearBits# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_clearBits(void*,HsInt);
#ifdef PROFILE
static SInfo pf_hs_clearBits = {"NHC.Binary","NHC.Binary.hs_clearBits#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95clearBits_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_clearBits(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_clearBits);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Binary/ClearBits.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+12)
#define CT_v201	((void*)startLabel+44)
#define F0_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+52)
#define FN_NHC_46Binary_46hs_95clearBits	((void*)startLabel+64)
#define CT_v203	((void*)startLabel+88)
#define CF_NHC_46Binary_46hs_95clearBits	((void*)startLabel+96)
#define CT_v205	((void*)startLabel+156)
#define FN_LAMBDA198	((void*)startLabel+192)
#define CT_v207	((void*)startLabel+216)
#define F0_LAMBDA198	((void*)startLabel+224)
#define ST_v204	((void*)startLabel+232)
#define ST_v206	((void*)startLabel+253)
#define ST_v202	((void*)startLabel+286)
#define ST_v200	((void*)startLabel+310)
extern Node TM_NHC_46Binary[];
void FR_NHC_46Binary_46hs_95clearBits_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46Binary[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v201)
,	/* FN_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v203)
,	/* FN_NHC_46Binary_46hs_95clearBits: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v202)
,	/* CT_v203: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95clearBits: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v205)
,};
Node FN_NHC_46Binary_46clearBits[] = {
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 140001
, useLabel(ST_v204)
,	/* CT_v205: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46Binary_46clearBits[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46clearBits),2)
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA198),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v207)
,	/* FN_LAMBDA198: (byte 0) */
  useLabel(TMSUB_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 150011
, useLabel(ST_v206)
,	/* CT_v207: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA198: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA198),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v204: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,99)
, bytes2word(108,101,97,114)
, bytes2word(66,105,116,115)
,	/* ST_v206: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(97,114,121,46)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
, bytes2word(115,58,49,53)
, bytes2word(58,49,49,45)
, bytes2word(49,53,58,51)
,	/* ST_v202: (byte 2) */
  bytes2word(49,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,97,114,121)
, bytes2word(46,104,115,95)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
,	/* ST_v200: (byte 2) */
  bytes2word(115,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,97,114,121)
, bytes2word(46,104,115,95)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
, bytes2word(115,35,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_clearBits" NHC.Binary.hs_clearBits# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_clearBits(void*,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46Binary_46hs_95clearBits_35 = {"NHC.Binary","NHC.Binary.hs_clearBits#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95clearBits_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_clearBits(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46Binary_46hs_95clearBits_35);
  C_RETURN(nodeptr);
}
